OSDN Git Service

set version as 1.4.5-snapshot2
[howm/howm.git] / howm.el
diff --git a/howm.el b/howm.el
index 06a52d8..c66e974 100644 (file)
--- a/howm.el
+++ b/howm.el
@@ -1,10 +1,12 @@
 ;;; howm.el --- Wiki-like note-taking tool
+;;; -*- Emacs-Lisp -*-
+;;; howm.el.  Generated from howm.el.in by configure.
 
-;; Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2015, 2016, 2017 HIRAOKA Kazuyuki
+;; Copyright (C) 2002, 2003, 2004, 2005-2018 HIRAOKA Kazuyuki
 
;; Author: HIRAOKA Kazuyuki <khi@users.sourceforge.jp>
;; URL: http://howm.osdn.jp
;; Version: 1.4.3
 ;; Package-Requires: ((cl-lib "0.5"))
 
 ;; This program is free software; you can redistribute it and/or modify
@@ -28,6 +30,8 @@
 ;;; See README.
 ;;; HOWM is acronym of "Hitori Otegaru Wiki Modoki".
 
+(defconst howm-version "1.4.5-snapshot")
+
 ;; Files [0]-[3] have only hierarchical dependencies,
 ;; whereas files in [5] have circular dependencies.
 ;; Each file in [5] provides itself first,
@@ -44,7 +48,6 @@
 
 ;;; [2] howm basic libraries
 
-(require 'howm-version)
 (require 'howm-vars)
 (require 'howm-common)
 
@@ -79,6 +82,7 @@
 ;;; http://noir.s7.xrea.com/pub/zaurus/howmz.el
 
 (howm-require-lang 'en)
+(howm-require-lang 'fr)
 (howm-require-lang 'ja)
 
 ;;; security fix [2006-12-16]
@@ -1,10 +1,12 @@
 
-;; Author: HIRAOKA Kazuyuki <khi@users.sourceforge.jp>
-;; URL: http://howm.osdn.jp
-;; Version: 1.4.3
+;; Author: HIRAOKA Kazuyuki <khi@users.osdn.me>
+;; URL: https://howm.osdn.jp
+;; Version: 1.4.5-snapshot
 ;; Package-Requires: ((cl-lib "0.5"))
 